
/* Generated data (by glib-mkenums) */

#ifndef __SHELL_ENUM_TYPES_H__
#define __SHELL_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./shell-app.h" */
GType shell_app_state_get_type (void) G_GNUC_CONST;
#define SHELL_TYPE_APP_STATE (shell_app_state_get_type())

/* enumerations from "./shell-global.h" */
GType shell_cursor_get_type (void) G_GNUC_CONST;
#define SHELL_TYPE_CURSOR (shell_cursor_get_type())

/* enumerations from "./shell-keybinding-modes.h" */
GType shell_key_binding_mode_get_type (void) G_GNUC_CONST;
#define SHELL_TYPE_KEY_BINDING_MODE (shell_key_binding_mode_get_type())

/* enumerations from "./shell-network-agent.h" */
GType shell_network_agent_response_get_type (void) G_GNUC_CONST;
#define SHELL_TYPE_NETWORK_AGENT_RESPONSE (shell_network_agent_response_get_type())

G_END_DECLS

#endif /* !__SHELL_ENUM_TYPES_H__ */

/* Generated data ends here */

